==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/comment/messages/nl/base.php <==
<?php
return array (
  '<strong>Confirm</strong> comment deleting' => '<strong>Bevestig</strong> reactie verwijderen',
  '<strong>Delete</strong> comment?' => '<strong>Reactie verwijderen</strong>?',
  '<strong>Permalink</strong> to this comment' => '<strong>Permalink</strong> naar deze reactie',
  'Cancel' => 'Annuleer',
  'Cancel Edit' => 'Annuleer bewerking',
  'Comment' => 'Reactie',
  'Comment could not be saved!' => 'Reactie kon niet worden opgeslagen!',
  'Comment has been deleted' => 'Reactie is verwijderd',
  'Comment of blocked user.' => 'Reactie van een geblokkeerde gebruiker.',
  'Comments' => 'Reacties',
  'Confirm' => 'Bevestig',
  'Delete' => 'Verwijder',
  'Do you really want to delete this comment?' => 'Wilt u deze reactie echt verwijderen?',
  'Edit' => 'Bewerk',
  'Edit your comment...' => 'Bewerk je reactie...',
  'Permalink' => 'Permalink',
  'Read full comment...' => 'Lees het volledige bericht...',
  'Reason' => 'Reden',
  'Reply' => 'Antwoord',
  'Send a notification to author' => 'Stuur een melding naar de schrijver',
  'Show' => 'Laten zien',
  'Show all {total} comments' => 'Toon alle {total} reacties',
  'Show {count} more comments' => 'Toon nog {count} reacties',
  'The comment must not be empty!' => 'De opmerking mag niet leeg zijn!',
  'Whenever a new comment was written.' => 'Wanneer er een nieuwe reactie is geschreven.',
  'Write a new comment...' => 'Geef een nieuwe reactie...',
  'Write a new reply...' => 'Schrijf een nieuw antwoord ...',
  'comment' => 'Reactie',
  '{displayName} wrote a new comment ' => '{displayName} schreef een nieuwe reactie',
);

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/comment/messages/nl/base.php <==
<?php
return array (
  '<strong>Confirm</strong> comment deleting' => '<strong>Bevestig</strong> reactie verwijderen',
  '<strong>Delete</strong> comment?' => '<strong>Reactie verwijderen</strong>?',
  '<strong>Permalink</strong> to this comment' => '<strong>Permalink</strong> naar deze reactie',
  'Cancel' => 'Annuleer',
  'Cancel Edit' => 'Annuleer bewerking',
  'Comment' => 'Reactie',
  'Comment could not be saved!' => 'Reactie kon niet worden opgeslagen!',
  'Comment has been deleted' => 'Reactie is verwijderd',
  'Comment of blocked user.' => 'Reactie van een geblokkeerde gebruiker.',
  'Comments' => 'Reacties',
  'Confirm' => 'Bevestig',
  'Delete' => 'Verwijder',
  'Do you really want to delete this comment?' => 'Wilt u deze reactie echt verwijderen?',
  'Edit' => 'Bewerk',
  'Edit your comment...' => 'Bewerk je reactie...',
  'Permalink' => 'Permalink',
  'Read full comment...' => 'Lees het volledige bericht...',
  'Reason' => 'Reden',
  'Reply' => 'Antwoord',
  'Send a notification to author' => 'Stuur een melding naar de schrijver',
  'Show' => 'Laten zien',
  'Show next {count} comments' => 'Toon volgende {count} reacties',
  'Show previous {count} comments' => 'Toon eerdere {count} reacties',
  'The comment must not be empty!' => 'De opmerking mag niet leeg zijn!',
  'Whenever a new comment was written.' => 'Wanneer er een nieuwe reactie is geschreven.',
  'Write a new comment...' => 'Geef een nieuwe reactie...',
  'Write a new reply...' => 'Schrijf een nieuw antwoord ...',
  'comment' => 'Reactie',
  '{displayName} wrote a new comment ' => '{displayName} schreef een nieuwe reactie',
);
